@@ -21,7 +21,16 @@ def test_api_group_order():
         pytest.fail("ApiGroup class not found in resource.py")
 
     api_groups = api_group_class[0]
-    api_group_names = [node.target.id for node in api_groups.body]
+    api_group_names: List[str] = []
+
+    for _api in api_groups.body:
+        try:
+            # When defined with type `IO_OCP: str = "io.openshiftapi"`
+            api_group_names.append(_api.target.id)
+        except AttributeError:
+            # When defined without type `IO_OCP = "io.openshiftapi"`
+            api_group_names.append(_api.targets[0].id)
+
     sorted_api_group_names = sorted(api_group_names, key=lambda x: x.replace("_", " "))
     errors: Set[str] = set()
     for _diff in difflib.Differ().compare(api_group_names, sorted_api_group_names):
@@ -29,6 +38,5 @@ def test_api_group_order():
             _err_diff = _diff.split(" ")[-1]
             errors.add(_err_diff)
 
-    assert not errors, (
-        f"ApiGroup class should be sorted alphabetically. Missed places ApiGroups: {'\n'.join(list(errors))}"
-    )
+    _errors_str = "\n".join(list(errors))
+    assert not errors, f"ApiGroup class should be sorted alphabetically. Missed places ApiGroups: {_errors_str}"
